@@ -598,8 +598,10 @@ CREATE TABLE vm_disk_samples_history
    minutes_in_status DECIMAL(7,2) NOT NULL DEFAULT 1,
    vm_disk_actual_size_mb INTEGER NOT NULL,
    read_rate_bytes_per_second INTEGER,
+   read_ops_per_second INTEGER,
    read_latency_seconds DECIMAL(18,9),
    write_rate_bytes_per_second  INTEGER,
+   write_ops_per_second  INTEGER,
    write_latency_seconds DECIMAL(18,9),
    flush_latency_seconds DECIMAL(18,9),
    vm_disk_configuration_version INTEGER REFERENCES vm_disk_configuration (history_id),
@@ -621,10 +623,14 @@ CREATE TABLE vm_disk_hourly_history
    vm_disk_actual_size_mb INTEGER NOT NULL,
    read_rate_bytes_per_second INTEGER,
    max_read_rate_bytes_per_second INTEGER,
+   read_ops_per_second INTEGER,
+   max_read_ops_per_second INTEGER,
    read_latency_seconds DECIMAL(18,9),
    max_read_latency_seconds DECIMAL(18,9),
-   write_rate_bytes_per_second  INTEGER,
-   max_write_rate_bytes_per_second  INTEGER,
+   write_rate_bytes_per_second INTEGER,
+   max_write_rate_bytes_per_second INTEGER,
+   write_ops_per_second INTEGER,
+   max_write_ops_per_second INTEGER,
    write_latency_seconds DECIMAL(18,9),
    max_write_latency_seconds DECIMAL(18,9),
    flush_latency_seconds DECIMAL(18,9),
@@ -648,10 +654,14 @@ CREATE TABLE vm_disk_daily_history
    vm_disk_actual_size_mb INTEGER NOT NULL,
    read_rate_bytes_per_second INTEGER,
    max_read_rate_bytes_per_second INTEGER,
+   read_ops_per_second INTEGER,
+   max_read_ops_per_second INTEGER,
    read_latency_seconds DECIMAL(18,9),
    max_read_latency_seconds DECIMAL(18,9),
-   write_rate_bytes_per_second  INTEGER,
-   max_write_rate_bytes_per_second  INTEGER,
+   write_rate_bytes_per_second INTEGER,
+   max_write_rate_bytes_per_second INTEGER,
+   write_ops_per_second INTEGER,
+   max_write_ops_per_second INTEGER,
    write_latency_seconds DECIMAL(18,9),
    max_write_latency_seconds DECIMAL(18,9),
    flush_latency_seconds DECIMAL(18,9),
